@@ -4,14 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTATTRIBUTE_H
-#define MAILTRANSPORT_TRANSPORTATTRIBUTE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
 #include <attribute.h>
 
-namespace MailTransport {
+namespace MailTransport
+{
 class Transport;
 
 /**
@@ -46,7 +46,7 @@ public:
       Returns the transport id to use for sending this message.
       @see TransportManager.
     */
-    int transportId() const;
+    Q_REQUIRED_RESULT int transportId() const;
 
     /**
       Returns the transport object corresponding to the transport id contained
@@ -65,4 +65,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTATTRIBUTE_H
